%global _hardened_build 1
%global __provides_exclude_from %{?__provides_exclude_from:%{__provides_exclude_from}|}^%{perl_vendorarch}/auto/.*\\.so$

Summary:          IPMI (Intelligent Platform Management Interface) library and tools
Name:             OpenIPMI
Version:          2.0.33
Release:          5%{?dist}
License:          LGPLv2+ and GPLv2+ or BSD
URL:              http://sourceforge.net/projects/openipmi/
Source0:          http://downloads.sourceforge.net/openipmi/%{name}-%{version}.tar.gz
Source1:          openipmi.sysconf
Source2:          openipmi-helper
Source3:          ipmi.service

BuildRequires:    make automake autoconf libtool pkgconfig
BuildRequires:    gdbm-devel glib2-devel net-snmp-devel ncurses-devel
BuildRequires:    swig python3-devel perl-devel perl-generators
BuildRequires:    openssl-devel readline-devel systemd
Requires:         %{name}-libs = %{version}-%{release}
%{?systemd_requires}

%description
The Open IPMI project aims to develop an open code base to allow access to
platform information using Intelligent Platform Management Interface (IPMI).
OpenIPMI will connect with an IPMI controller, detect any management
controllers on the bus, get their SDRs, manage all the entities in the
system, manage the event log, and a host of other things.


%package libs
Summary:          OpenIPMI runtime libraries

%description libs
Runtime libraries for shared binaries and applications.


%package devel
Summary:          Libraries and header files for OpenIPMI development
Requires:         pkgconfig
Requires:         %{name} = %{version}-%{release}
Requires:         %{name}-libs = %{version}-%{release}

%description devel
Libraries and header files to develop applications with OpenIPMI.


%package lanserv
Summary:          Emulates an IPMI network listener
Requires:         %{name} = %{version}-%{release}

%description lanserv
This package contains a network IPMI listener.


%package perl
Summary:          Perl bindings for OpenIPMI
Requires:         %{name}-libs = %{version}-%{release}
Requires:         perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))

%description perl
Perl language bindings for OpenIPMI.


%package -n python3-openipmi
Summary:          Python bindings for OpenIPMI
Requires:         %{name}-libs = %{version}-%{release}
Provides:         %{name}-python = %{version}-%{release}
Provides:         %{name}-python%{?_isa} = %{version}-%{release}
Provides:         python-OpenIPMI = %{version}-%{release}

%description -n python3-openipmi
Python language bindings for OpenIPMI.


%prep
%autosetup


%build
export CFLAGS="%{optflags} -fPIC -z now -fno-strict-aliasing"
export LDFLAGS="%{build_ldflags} -Wl,--as-needed"

%configure --disable-dependency-tracking \
           --disable-static \
           --with-pythoninstall=%{python3_sitearch} \
           --with-python=%{__python3} \
           --with-tcl=no \
           --with-tkinter=no

sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

%make_build


%install
%make_install

install -D -m 644 %SOURCE1 %{buildroot}%{_sysconfdir}/sysconfig/ipmi
install -D -m 755 %SOURCE2 %{buildroot}%{_libexecdir}/openipmi-helper
install -D -m 644 %SOURCE3 %{buildroot}%{_unitdir}/ipmi.service
install -d %{buildroot}%{_sysconfdir}/modprobe.d

rm %{buildroot}%{_mandir}/man1/openipmigui.1 %{buildroot}%{_libdir}/*.la
rm %{buildroot}%{python3_sitearch}/*.la

echo ".so man1/openipmicmd.1" > %{buildroot}%{_mandir}/man1/ipmicmd.1
echo ".so man1/openipmish.1" > %{buildroot}%{_mandir}/man1/ipmish.1


%post
%systemd_post ipmi.service

%preun
%systemd_preun ipmi.service

%postun
%systemd_postun_with_restart ipmi.service


%files
%license COPYING COPYING.BSD COPYING.LIB
%doc CONFIGURING_FOR_LAN FAQ README README.Force README.MotorolaMXP
%config(noreplace) %{_sysconfdir}/sysconfig/ipmi
%{_unitdir}/ipmi.service
%{_bindir}/ipmicmd
%{_bindir}/ipmish
%{_bindir}/ipmi_ui
%{_bindir}/openipmicmd
%{_bindir}/openipmish
%{_bindir}/rmcp_ping
%{_bindir}/solterm
%{_bindir}/openipmi_eventd
%{_libexecdir}/openipmi-helper
%{_mandir}/man1/ipmi_ui*
%{_mandir}/man1/openipmicmd*
%{_mandir}/man1/openipmish*
%{_mandir}/man1/rmcp_ping*
%{_mandir}/man1/solterm*
%{_mandir}/man1/ipmish*
%{_mandir}/man1/ipmicmd*
%{_mandir}/man1/openipmi_eventd*
%{_mandir}/man7/ipmi_cmdlang*
%{_mandir}/man7/openipmi_conparms*


%files libs
%{_libdir}/libOpenIPMI*.so.*


%files devel
%{_includedir}/OpenIPMI
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc


%files lanserv
%config(noreplace) %{_sysconfdir}/ipmi/ipmisim1.emu
%config(noreplace) %{_sysconfdir}/ipmi/lan.conf
%dir %{_sysconfdir}/ipmi
%{_bindir}/ipmilan
%{_bindir}/ipmi_sim
%{_bindir}/sdrcomp
%{_libdir}/libIPMIlanserv.so.*
%{_mandir}/man8/ipmilan.8*
%{_mandir}/man1/ipmi_sim.1*
%{_mandir}/man5/ipmi_lan.5*
%{_mandir}/man5/ipmi_sim_cmd.5*


%files perl
%attr(644,root,root) %{perl_vendorarch}/OpenIPMI.pm
%{perl_vendorarch}/auto/OpenIPMI


%files -n python3-openipmi
%{python3_sitearch}/*OpenIPMI*
%{python3_sitearch}/__pycache__/OpenIPMI.*.pyc


%changelog
* Tue Sep 19 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.33-5
- Rebuilt for python 3.11

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.33-4
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.33-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 2.0.33-2
- Rebuilt for OpenCloudOS Stream 23

* Mon Jul 18 2022 rockerzhu <rockerzhu@tencent.com> - 2.0.33-1
- Initial build
